



ncdump -h http://geoport-dev.whoi.edu/thredds/dodsC/estofs/atlantic
IF %ERRORLEVEL% NEQ 0 exit 1
ncdump -h https://data.nodc.noaa.gov/thredds/dodsC/ioos/sccoos/scripps_pier/scripps_pier-2016.nc
IF %ERRORLEVEL% NEQ 0 exit 1
exit 0
